package com.mortals.xhx.module.user.service;

import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Result;
import com.mortals.framework.service.ICRUDService;
import com.mortals.framework.service.IUser;
import com.mortals.xhx.module.menu.model.MenuEntity;
import com.mortals.xhx.module.user.model.UserEntity;

import java.util.List;
import java.util.Set;

/**
* UserService
*
* 用户信息业务 service接口
*
* @author zxfei
* @date 2022-05-25
*/
public interface UserService extends ICRUDService<UserEntity,Long>{
    /**
     * 用户登录
     *
     * @param loginName 登录用户名
     * @param password  登录密码
     * @param loginIp   登录IP
     * @return
     * @throws AppException
     */
    UserEntity doLogin(String loginName, String password, String loginIp) throws AppException;

    /**
     * 校验用户名与密码是否正确
     *
     * @param loginName
     * @param password
     * @return
     * @throws AppException
     */
    UserEntity doCheckUser(String loginName, String password) throws AppException;

    /**
     * 检查用户是否存在
     *
     * @param loginName 登录用户名
     * @param userId    密码
     * @return
     */
    boolean existUser(String loginName, Long userId) throws AppException;

    /**
     * 通过登录用户获取菜单功能权限
     *
     * @param user
     * @return
     */
    List<MenuEntity> findOutlookBarList(IUser user);


    /**
     * 查询用户所有有权限的菜单ID
     *
     * @param userEntity
     * @return
     */
    Set<Long> findAllAuthIds(UserEntity userEntity) throws AppException;

    /**
     * 查询用户记录
     *
     * @param platformId
     * @param params
     * @param currPage
     * @param prePageResult
     * @return
     * @throws AppException
     */
    Result<UserEntity> find(Long platformId, UserEntity params, int currPage, int prePageResult) throws AppException;


    /**
     * 用户修改密码
     *
     * @param loginName
     * @param oldPwd
     * @param newPwd
     * @return
     * @throws AppException
     */
    boolean updateUserPwd(String loginName, String oldPwd, String newPwd) throws AppException;




}